@@ -1,5 +1,7 @@
 use structopt::StructOpt;
-use ws_tool::ConnBuilder;
+use tracing::Level;
+use tracing_subscriber::util::SubscriberInitExt;
+use ws_tool::{codec::AsyncWsStringCodec, ClientBuilder};
 
 /// websocket client connect to binance futures websocket
 #[derive(StructOpt)]
@@ -14,21 +16,26 @@ struct Args {
 
 #[tokio::main]
 async fn main() -> Result<(), ()> {
-    pretty_env_logger::init();
+    tracing_subscriber::fmt::fmt()
+        .with_max_level(Level::DEBUG)
+        .finish()
+        .try_init()
+        .expect("failed to init log");
     let args = Args::from_args();
     let channels = args.channels.join("/");
-    let mut builder = ConnBuilder::new(&format!(
+    let mut builder = ClientBuilder::new(&format!(
         "wss://fstream.binance.com/stream?streams={}",
         channels
     ));
     if let Some(proxy) = args.proxy {
         builder = builder.proxy(&proxy)
     }
-    let mut client = builder.build().await.unwrap();
-    client.handshake().await.unwrap();
+    let mut client = builder
+        .async_connect(AsyncWsStringCodec::check_fn)
+        .await
+        .unwrap();
 
-    while let Some(Ok(resp)) = client.read().await {
-        let msg = String::from_utf8(resp.payload_data_unmask().to_vec()).unwrap();
+    while let Ok((_, msg)) = client.receive().await {
         println!("{}", msg.trim());
     }
     Ok(())
